@@ -18,8 +18,6 @@ limitations under the License.
 package v1
 
 import (
-	"encoding/json"
-
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 )
@@ -58,12 +56,18 @@ type TraitSpec struct {
 	Configuration TraitConfiguration `json:"configuration"`
 }
 
-// +kubebuilder:validation:Type=object
 // TraitConfiguration --
 type TraitConfiguration struct {
-	json.RawMessage `json:",inline"`
+	RawMessage `json:",inline"`
 }
 
+// RawMessage is a raw encoded JSON value.
+// It implements Marshaler and Unmarshaler and can
+// be used to delay JSON decoding or precompute a JSON encoding.
+// +kubebuilder:validation:Type=object
+// +kubebuilder:validation:Format=""
+type RawMessage []byte
+
 // +kubebuilder:object:generate=false
 // Configurable --
 type Configurable interface {
@@ -146,7 +150,91 @@ type ResourceCondition interface {
 }
 
 // Flow is an unstructured object representing a Camel Flow in YAML/JSON DSL
-// +kubebuilder:validation:Type=object
 type Flow struct {
-	json.RawMessage `json:",inline"`
+	RawMessage `json:",inline"`
+}
+
+// RuntimeProvider --
+type RuntimeProvider string
+
+const (
+	// RuntimeProviderQuarkus --
+	RuntimeProviderQuarkus RuntimeProvider = "quarkus"
+)
+
+// ResourceType --
+type ResourceType string
+
+// ResourceSpec --
+type ResourceSpec struct {
+	DataSpec  `json:",inline"`
+	Type      ResourceType `json:"type,omitempty"`
+	MountPath string       `json:"mountPath,omitempty"`
+}
+
+const (
+	// ResourceTypeData --
+	ResourceTypeData ResourceType = "data"
+	// ResourceTypeOpenAPI --
+	ResourceTypeOpenAPI ResourceType = "openapi"
+)
+
+// SourceSpec --
+type SourceSpec struct {
+	DataSpec `json:",inline"`
+	Language Language `json:"language,omitempty"`
+	// Loader is an optional id of the org.apache.camel.k.RoutesLoader that will
+	// interpret this source at runtime
+	Loader string `json:"loader,omitempty"`
+	// Interceptors are optional identifiers the org.apache.camel.k.RoutesLoader
+	// uses to pre/post process sources
+	Interceptors []string `json:"interceptors,omitempty"`
+	// Type defines the kind of source described by this object
+	Type SourceType `json:"type,omitempty"`
+	// List of property names defined in the source (e.g. if type is "template")
+	PropertyNames []string `json:"property-names,omitempty"`
+}
+
+type SourceType string
+
+const (
+	SourceTypeDefault  SourceType = ""
+	SourceTypeTemplate SourceType = "template"
+)
+
+// DataSpec --
+type DataSpec struct {
+	Name        string `json:"name,omitempty"`
+	Content     string `json:"content,omitempty"`
+	ContentRef  string `json:"contentRef,omitempty"`
+	ContentKey  string `json:"contentKey,omitempty"`
+	Compression bool   `json:"compression,omitempty"`
+}
+
+// Language --
+type Language string
+
+const (
+	// LanguageJavaSource --
+	LanguageJavaSource Language = "java"
+	// LanguageGroovy --
+	LanguageGroovy Language = "groovy"
+	// LanguageJavaScript --
+	LanguageJavaScript Language = "js"
+	// LanguageXML --
+	LanguageXML Language = "xml"
+	// LanguageKotlin --
+	LanguageKotlin Language = "kts"
+	// LanguageYaml --
+	LanguageYaml Language = "yaml"
+)
+
+// Languages is the list of all supported languages
+var Languages = []Language{
+	LanguageJavaSource,
+	LanguageGroovy,
+	LanguageJavaScript,
+	LanguageXML,
+	LanguageKotlin,
+	LanguageYaml,
 }
