@@ -89,3 +89,11 @@ func KameletCatalog(ctx context.Context, c client.Client, namespace string) erro
 
 	return nil
 }
+
+// KameletViewerRole installs the role that allows any user ro access kamelets in the global namespace
+func KameletViewerRole(ctx context.Context, c client.Client, namespace string) error {
+	if err := Resource(ctx, c, namespace, true, IdentityResourceCustomizer, "user-global-kamelet-viewer-role.yaml"); err != nil {
+		return err
+	}
+	return Resource(ctx, c, namespace, true, IdentityResourceCustomizer, "user-global-kamelet-viewer-role-binding.yaml")
+}
