@@ -22,18 +22,15 @@ import (
 	"sort"
 	"strings"
 
-	infp "gopkg.in/inf.v0"
-
-	"github.com/pkg/errors"
-	"github.com/scylladb/go-set/strset"
-
-	corev1 "k8s.io/api/core/v1"
-	"k8s.io/apimachinery/pkg/api/resource"
-
-	k8sclient "sigs.k8s.io/controller-runtime/pkg/client"
-
 	v1 "github.com/apache/camel-k/pkg/apis/camel/v1"
 	"github.com/apache/camel-k/pkg/util"
+	"github.com/pkg/errors"
+	"github.com/scylladb/go-set/strset"
+	infp "gopkg.in/inf.v0"
+	corev1 "k8s.io/api/core/v1"
+	"k8s.io/apimachinery/pkg/api/resource"
+	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
+	k8sclient "sigs.k8s.io/controller-runtime/pkg/client"
 )
 
 // The JVM trait is used to configure the JVM that runs the integration.
@@ -42,11 +39,11 @@ import (
 type jvmTrait struct {
 	BaseTrait `property:",squash"`
 	// Activates remote debugging, so that a debugger can be attached to the JVM, e.g., using port-forwarding
-	Debug bool `property:"debug" json:"debug,omitempty"`
+	Debug *bool `property:"debug" json:"debug,omitempty"`
 	// Suspends the target JVM immediately before the main class is loaded
-	DebugSuspend bool `property:"debug-suspend" json:"debugSuspend,omitempty"`
+	DebugSuspend *bool `property:"debug-suspend" json:"debugSuspend,omitempty"`
 	// Prints the command used the start the JVM in the container logs (default `true`)
-	PrintCommand bool `property:"print-command" json:"printCommand,omitempty"`
+	PrintCommand *bool `property:"print-command" json:"printCommand,omitempty"`
 	// Transport address at which to listen for the newly launched JVM (default `*:5005`)
 	DebugAddress string `property:"debug-address" json:"debugAddress,omitempty"`
 	// A list of JVM options
@@ -57,7 +54,7 @@ func newJvmTrait() Trait {
 	return &jvmTrait{
 		BaseTrait:    NewBaseTrait("jvm", 2000),
 		DebugAddress: "*:5005",
-		PrintCommand: true,
+		PrintCommand: util.BoolP(true),
 	}
 }
 
@@ -118,14 +115,22 @@ func (t *jvmTrait) Apply(e *Environment) error {
 	args := container.Args
 
 	// Remote debugging
-	if t.Debug {
+	if util.IsTrue(t.Debug) {
 		suspend := "n"
-		if t.DebugSuspend {
+		if util.IsTrue(t.DebugSuspend) {
 			suspend = "y"
 		}
 		args = append(args,
 			fmt.Sprintf("-agentlib:jdwp=transport=dt_socket,server=y,suspend=%s,address=%s",
 				suspend, t.DebugAddress))
+
+		// Add label to mark the pods with debug enabled
+		e.Resources.VisitPodTemplateMeta(func(meta *metav1.ObjectMeta) {
+			if meta.Labels == nil {
+				meta.Labels = make(map[string]string)
+			}
+			meta.Labels["camel.apache.org/debug"] = "true"
+		})
 	}
 
 	hasHeapSizeOption := false
@@ -162,7 +167,7 @@ func (t *jvmTrait) Apply(e *Environment) error {
 	args = append(args, "-cp", strings.Join(items, ":"))
 	args = append(args, e.CamelCatalog.Runtime.ApplicationClass)
 
-	if t.PrintCommand {
+	if util.IsNilOrTrue(t.PrintCommand) {
 		args = append([]string{"exec", "java"}, args...)
 		container.Command = []string{"/bin/sh", "-c"}
 		cmd := strings.Join(args, " ")
