@@ -23,7 +23,7 @@ apidir=$location/../pkg/apis/camel
 echo "Generating CRDs..."
 
 cd $apidir
-go run sigs.k8s.io/controller-tools/cmd/controller-gen crd paths=./... output:crd:artifacts:config=false output:crd:dir=../../../deploy/crds crd:crdVersions=v1beta1
+$CONTROLLER_GEN crd paths=./... output:crd:artifacts:config=false output:crd:dir=../../../deploy/crds crd:crdVersions=v1beta1
 
 # cleanup
 rm -r ./config
@@ -61,7 +61,8 @@ deploy_crd() {
   deploy_crd_file ./deploy/crds/camel.apache.org_$plural.yaml \
     ./deploy/crd-$name.yaml \
     ./helm/camel-k/crds/crd-$name.yaml \
-    ./deploy/olm-catalog/camel-k-dev/$version/$plural.camel.apache.org.crd.yaml
+    ./deploy/olm-catalog/camel-k-dev/$version/$plural.camel.apache.org.crd.yaml \
+    ./config/crd/bases/camel.apache.org_$plural.yaml
 }
 
 deploy_crd build builds
